@@ -1,4 +1,4 @@
-from typing import Optional, Sequence, List, Set, Callable
+from typing import Callable, List, Optional, Sequence, Set
 
 
 class CasedModel:
@@ -39,4 +39,4 @@ def first_word_untouched_rest_lower(s: str) -> str:
 
 def first_word_untouched_rest_capitalized(s: str) -> str:
     parts = s.split()
-    return f'{parts[0]} {" ".join([part.capitalize() for part in parts[1:]])}'
\ No newline at end of file
+    return f'{parts[0]} {" ".join([part.capitalize() for part in parts[1:]])}'
