@@ -14,8 +14,8 @@ class CategoryModel(NestedModel, HasLogo):
     logo_svg_text: Optional[str] = None
     logo_base64: Optional[str] = None
     logo_fa_icon_class_str: Optional[str] = None
-    parents: Optional[Sequence['NestedModel']] = field(default_factory=lambda: [])
+    parents: Optional[Sequence["NestedModel"]] = field(default_factory=lambda: [])
     children: WeakList = field(default_factory=lambda: WeakList())
 
     def __post_init__(self):
-        super().__init__()
\ No newline at end of file
+        super().__init__()
