@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from typing import Dict, TYPE_CHECKING, Protocol
+from typing import TYPE_CHECKING, Dict, Protocol
 
 if TYPE_CHECKING:
     from derobertis_cv.models.skill_experience import SkillExperience
@@ -10,7 +10,6 @@ class ExperienceAttributes(Protocol):
 
 
 class SkillExperienceScale(ABC):
-
     @classmethod
     @abstractmethod
     def experience_to_level(cls, exp: ExperienceAttributes) -> int:
@@ -23,12 +22,7 @@ class SkillExperienceScale(ABC):
 
 
 class HoursExperienceScale(SkillExperienceScale):
-    cutoffs: Dict[int, float] = {
-        2: 100,
-        3: 500,
-        4: 1000,
-        5: 3000
-    }
+    cutoffs: Dict[int, float] = {2: 100, 3: 500, 4: 1000, 5: 3000}
 
     @classmethod
     def experience_to_level(cls, exp: ExperienceAttributes) -> int:
@@ -45,9 +39,9 @@ class HoursExperienceScale(SkillExperienceScale):
     @classmethod
     def description_for_level(cls, level: int) -> str:
         if level == 1:
-            return f'20 - {cls.cutoffs[2]:,.0f}'
+            return f"20 - {cls.cutoffs[2]:,.0f}"
         if level < 5:
-            return f'{cls.cutoffs[level]:,.0f} - {cls.cutoffs[level + 1]:,.0f}'
+            return f"{cls.cutoffs[level]:,.0f} - {cls.cutoffs[level + 1]:,.0f}"
         if level == 5:
-            return f'{cls.cutoffs[5]:,.0f}+'
-        raise ValueError(f'invalid level {level}')
\ No newline at end of file
+            return f"{cls.cutoffs[5]:,.0f}+"
+        raise ValueError(f"invalid level {level}")
