@@ -8,4 +8,4 @@ class GradeBreakdownModel:
 
     def __post_init__(self):
         if sum(self.categories.values()) != 1:
-            raise ValueError('breakdown grade weights must sum to 1')
\ No newline at end of file
+            raise ValueError("breakdown grade weights must sum to 1")
