@@ -2,7 +2,6 @@ from abc import ABC, abstractmethod
 
 
 class SkillLevelScaler(ABC):
-
     @classmethod
     @abstractmethod
     def level_to_scaled_level(cls, level: int) -> int:
@@ -10,7 +9,6 @@ class SkillLevelScaler(ABC):
 
 
 class FiveToThreeScaler(SkillLevelScaler):
-
     @classmethod
     def level_to_scaled_level(cls, level: int) -> int:
         if level in (1, 2):
@@ -19,4 +17,4 @@ class FiveToThreeScaler(SkillLevelScaler):
             return 2
         if level in (4, 5):
             return 3
-        raise ValueError(f'invalid level {level}')
\ No newline at end of file
+        raise ValueError(f"invalid level {level}")
