@@ -1,11 +1,11 @@
 from dataclasses import dataclass, field
-from typing import Sequence, Optional, Set
+from typing import Optional, Sequence, Set
 
 from weakreflist import WeakList
 
 
 class NestedModel:
-    parents: Optional[Sequence['NestedModel']]
+    parents: Optional[Sequence["NestedModel"]]
     children: WeakList
 
     def __init__(self):
@@ -13,10 +13,10 @@ class NestedModel:
             for parent in self.parents:
                 parent.children.append(self)
 
-    def get_nested_children(self) -> Set['NestedModel']:
+    def get_nested_children(self) -> Set["NestedModel"]:
         all_children = set()
-        child: 'NestedModel'
+        child: "NestedModel"
         for child in self.children:
             all_children.add(child)
             all_children.update(child.get_nested_children())
-        return all_children
\ No newline at end of file
+        return all_children
