@@ -6,19 +6,19 @@ from derobertis_cv.pltemplates.logo import HasLogo
 
 
 class OrganizationCharacteristics(str, Enum):
-    WARM_WEATHER = 'warm_weather'
-    SMALL_TOWN = 'small_town'
-    MID_SIZE_CITY = 'mid_size_city'
-    LARGE_CITY = 'large_city'
-    INTERNATIONAL = 'international'
-    WEST_COAST = 'west coast'
-    FAMILY_CLOSE = 'family close'
-    REMOTE = 'remote'
-    MULTIPLE_LOCATIONS = 'multiple locations'
-    SPANISH_SPEAKING = 'spanish speaking'
-    FRENCH_SPEAKING = 'french speaking'
-    NOVA = 'northern virginia'
-    SUBURBAN = 'suburban'
+    WARM_WEATHER = "warm_weather"
+    SMALL_TOWN = "small_town"
+    MID_SIZE_CITY = "mid_size_city"
+    LARGE_CITY = "large_city"
+    INTERNATIONAL = "international"
+    WEST_COAST = "west coast"
+    FAMILY_CLOSE = "family close"
+    REMOTE = "remote"
+    MULTIPLE_LOCATIONS = "multiple locations"
+    SPANISH_SPEAKING = "spanish speaking"
+    FRENCH_SPEAKING = "french speaking"
+    NOVA = "northern virginia"
+    SUBURBAN = "suburban"
 
 
 @dataclass
@@ -37,4 +37,4 @@ class Organization(HasLogo):
 
     def __post_init__(self):
         if self.abbreviation is None:
-            self.abbreviation = self.title
\ No newline at end of file
+            self.abbreviation = self.title
