@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import Optional, TYPE_CHECKING, Sequence
+from typing import TYPE_CHECKING, Optional, Sequence
 
 from derobertis_cv.models.category import CategoryModel
 
@@ -9,8 +9,8 @@ if TYPE_CHECKING:
 
 @dataclass
 class CoursePrerequsitesModel:
-    required_courses: Optional[Sequence['CourseModel']] = None
-    recommended_courses: Optional[Sequence['CourseModel']] = None
+    required_courses: Optional[Sequence["CourseModel"]] = None
+    recommended_courses: Optional[Sequence["CourseModel"]] = None
     courses_description: Optional[str] = None
     technical_skills: Optional[Sequence[CategoryModel]] = None
-    technical_skills_description: Optional[str] = None
\ No newline at end of file
+    technical_skills_description: Optional[str] = None
