@@ -1,12 +1,12 @@
-from dataclasses import dataclass
 import datetime
-from typing import Union, Type, Optional
+from dataclasses import dataclass
+from typing import Optional, Type, Union
 
 import pandas as pd
 
 from derobertis_cv.models.experience_scale import (
-    SkillExperienceScale,
     HoursExperienceScale,
+    SkillExperienceScale,
 )
 from derobertis_cv.models.i_skill_experience import ISkillExperience
 from derobertis_cv.models.skill_experience_mixin import SkillExperienceMixin
