@@ -1,8 +1,11 @@
-from dataclasses import dataclass
 import datetime
-from typing import Type, Sequence
+from dataclasses import dataclass
+from typing import Sequence, Type
 
-from derobertis_cv.models.experience_scale import HoursExperienceScale, SkillExperienceScale
+from derobertis_cv.models.experience_scale import (
+    HoursExperienceScale,
+    SkillExperienceScale,
+)
 from derobertis_cv.models.i_skill_experience import ISkillExperience
 from derobertis_cv.models.skill_experience import SkillExperience
 from derobertis_cv.models.skill_experience_mixin import SkillExperienceMixin
