@@ -1,9 +1,9 @@
 import pyexlatex as pl
-import pyexlatex.table as lt
-import pyexlatex.presentation as lp
 import pyexlatex.graphics as lg
 import pyexlatex.layouts as ll
+import pyexlatex.presentation as lp
 import pyexlatex.resume as lr
+import pyexlatex.table as lt
 from pyexlatex.models.control.setcounter import SetCounter
 
 from derobertis_cv import plbuild
@@ -14,7 +14,7 @@ from derobertis_cv.pltemplates.syllabus import Syllabus
 
 model = get_fin_model_course()
 
-AUTHORS = [f'{model.course_id} - {model.title}']
+AUTHORS = [f"{model.course_id} - {model.title}"]
 
 DOCUMENT_CLASS = lr.Resume
 OUTPUT_LOCATION = plbuild.paths.DOCUMENTS_BUILD_PATH
@@ -22,16 +22,14 @@ HANDOUTS_OUTPUT_LOCATION = None
 
 
 def get_content():
-    return [
-        Syllabus(model=model)
-    ]
+    return [Syllabus(model=model)]
+
 
 DOCUMENT_CLASS_KWARGS = dict(
-    pre_env_contents=[SetCounter('secnumdepth', 0)],  # remove section numbering
+    pre_env_contents=[SetCounter("secnumdepth", 0)],  # remove section numbering
     contact_lines=[
         [model.current_period],
         [model.current_time],
-    ]
+    ],
 )
-OUTPUT_NAME = f'Financial Modeling Syllabus'
-
+OUTPUT_NAME = f"Financial Modeling Syllabus"
