@@ -12,13 +12,12 @@ HANDOUTS_OUTPUT_LOCATION = None
 
 num_levels = 5
 
+
 def get_content():
     return [
         *[SkillDot(level, max_level=num_levels) for level in range(1, num_levels + 1)],
     ]
 
-DOCUMENT_CLASS_KWARGS: Dict[str, Any] = dict(
-
-)
-OUTPUT_NAME = f'Skill Dot'
 
+DOCUMENT_CLASS_KWARGS: Dict[str, Any] = dict()
+OUTPUT_NAME = f"Skill Dot"
