@@ -1,4 +1,4 @@
-from typing import Dict, Any
+from typing import Any, Dict
 
 import pyexlatex as pl
 
@@ -7,8 +7,12 @@ from derobertis_cv.models.prereq import CoursePrerequsitesModel
 from derobertis_cv.models.resources import ResourceModel, ResourceSection
 from derobertis_cv.models.textbook import TextbookModel
 from derobertis_cv.pldata.constants.institutions import UF_NAME
-from derobertis_cv.pldata.course_categories import COURSE_CATEGORIES, FIN_MODEL_COURSE_CATEGORIES, \
-    FIN_MODEL_COURSE_MAIN_CATEGORIES, FIN_MODEL_COURSE_PREREQ_CATEGORIES
+from derobertis_cv.pldata.course_categories import (
+    COURSE_CATEGORIES,
+    FIN_MODEL_COURSE_CATEGORIES,
+    FIN_MODEL_COURSE_MAIN_CATEGORIES,
+    FIN_MODEL_COURSE_PREREQ_CATEGORIES,
+)
 from derobertis_cv.pldata.courses.general import get_grading_model
 from derobertis_cv.pldata.software import get_software_projects
 
@@ -17,24 +21,24 @@ def get_fin_model_course(**overrides: Dict[str, Any]) -> CourseModel:
     from derobertis_cv.pldata.universities import UF
 
     default_textbook = TextbookModel(
-        title='Financial Modeling',
-        author='Simon Benninga',
+        title="Financial Modeling",
+        author="Simon Benninga",
         required=False,
         description="""
 Textbook is only recommended. This book is very focused on Excel and we will be using both Excel
 and Python in the course. It is however useful as a reference for the Excel material and generally how
 to build the models.
         """.strip(),
-        publisher_details='Fourth Edition, MIT Press'
+        publisher_details="Fourth Edition, MIT Press",
     )
 
     default_prereqs = CoursePrerequsitesModel(
         required_courses=[
-            CourseModel('Business Finance', '', course_id='FIN 3403'),
+            CourseModel("Business Finance", "", course_id="FIN 3403"),
         ],
         recommended_courses=[
-            CourseModel('Debt and Money Markets', '', course_id='FIN 4243'),
-            CourseModel('Equity and Capital Markets', '', course_id='FIN 4504'),
+            CourseModel("Debt and Money Markets", "", course_id="FIN 4243"),
+            CourseModel("Equity and Capital Markets", "", course_id="FIN 4504"),
         ],
         courses_description="""
 FIN 3403 (Business Finance) is the minimum requirement. It is highly recommended that you have also taken
@@ -51,7 +55,7 @@ intermediate skills in Excel and no experience with Python. Ensure that you have
 If you have no Excel experience or some gaps in your experience but still want to
 take the course, take a look at the free Excel resources at the end of the syllabus and contact me if
 you have questions as you go through the resources.
-        """
+        """,
     )
 
     default_class_structure = [
@@ -68,7 +72,7 @@ completing the exercises as well. You are encouraged to discuss the lab exercise
 classmates, but everyone should complete the exercises on their own computer.      
                 """.strip()
             ],
-            title='A Typical Day'
+            title="A Typical Day",
         ),
         pl.SubSubSection(
             [
@@ -81,7 +85,7 @@ copy/paste as well as manually following someone’s specific steps. You can how
 classmates, so long as the final submission is entirely your own work.
                 """.strip()
             ],
-            title='Projects'
+            title="Projects",
         ),
         pl.SubSubSection(
             [
@@ -95,11 +99,12 @@ If you are not able to figure out the lab exercise in the time provided, I am ha
 appointment for a video call.
                 """.strip()
             ],
-            title='Questions?'
+            title="Questions?",
         ),
         pl.SubSubSection(
             [
-                pl.Model("""
+                pl.Model(
+                    """
 I will accept late projects, {{ "but I will subtract 10% from the grade for each day" | Bold  }} late. Projects are 
 {{ "due by midnight on the due date" | Bold }} and must be submitted to Canvas by this time. If you turn it in 
 five minutes after midnight, I will subtract 10%. Then each additional 10% subtraction happens at midnight on each 
@@ -111,9 +116,10 @@ you will lose
 10%. Then, starting 12:01 AM Thursday (Wednesday night), you are losing 20%. Then starting 12:01 Friday
 (Thursday night), you are losing 30%. But we review the project as a class that Thursday, you may only
 submit it up until that time on Thursday.
-                """.strip())
+                """.strip()
+                )
             ],
-            title='Late Policy'
+            title="Late Policy",
         ),
         pl.SubSubSection(
             [
@@ -136,7 +142,7 @@ material will continue to build on itself. You cannot afford to feel lost and do
 hope it will get better, it will only get worse as the course progresses.
                 """.strip()
             ],
-            title='How to be Successful in This Class'
+            title="How to be Successful in This Class",
         ),
         pl.SubSubSection(
             [
@@ -145,13 +151,13 @@ Projects may be turned in late for reduced credit but not after we have reviewed
 above.
                 """.strip()
             ],
-            title='Make-Up Policy'
+            title="Make-Up Policy",
         ),
     ]
 
     default_grading_model = get_grading_model()
 
-    software_project_names = ['fin-model-course', 'py-finstmt', 'sensitivity']
+    software_project_names = ["fin-model-course", "py-finstmt", "sensitivity"]
     default_software_projects = get_software_projects(
         include_projects=software_project_names,
         order=software_project_names,
@@ -160,102 +166,102 @@ above.
     py_video_and_interactive_tutorials = ResourceSection(
         [
             ResourceModel(
-                'Python from Scratch',
-                'https://open.cs.uwaterloo.ca/python-from-scratch/',
-                author='University of Waterloo'
+                "Python from Scratch",
+                "https://open.cs.uwaterloo.ca/python-from-scratch/",
+                author="University of Waterloo",
             )
         ],
-        'Interactive + Video tutorials',
+        "Interactive + Video tutorials",
     )
     py_interactive_tutorials = ResourceSection(
         [
             ResourceModel(
-                'Computer Science Circles',
-                'https://cscircles.cemc.uwaterloo.ca/',
-                author='University of Waterloo'
+                "Computer Science Circles",
+                "https://cscircles.cemc.uwaterloo.ca/",
+                author="University of Waterloo",
             ),
             ResourceModel(
-                'Learn Python 2',
-                'https://www.codecademy.com/learn/learn-python',
-                author='codecademy',
+                "Learn Python 2",
+                "https://www.codecademy.com/learn/learn-python",
+                author="codecademy",
                 description="""
 This one teaches Python 2, which is outdated, but the main difference in the covered material
 is just that the print function doesn't use parentheses in Python 2. So if you do this one then 
 just adjust how you call print for the class. There is also a Python 3 course but it requires the Pro plan.
-                """.strip()
+                """.strip(),
             ),
             ResourceModel(
-                'learnpython.org',
-                'https://www.learnpython.org/',
-                description='This is more fast paced'
+                "learnpython.org",
+                "https://www.learnpython.org/",
+                description="This is more fast paced",
             ),
         ],
-        'interactive tutorials',
+        "interactive tutorials",
     )
     py_video_tutorials = ResourceSection(
         [
             ResourceModel(
-                'YouTube Video Series',
-                'https://www.youtube.com/watch?v=Z1Yd7upQsXY&list=PLBZBJbE_rGRWeh5mIBhD-hhDwSEDxogDg&ab_channel=CSDojo',
-                author='CS Dojo'
+                "YouTube Video Series",
+                "https://www.youtube.com/watch?v=Z1Yd7upQsXY&list=PLBZBJbE_rGRWeh5mIBhD-hhDwSEDxogDg&ab_channel=CSDojo",
+                author="CS Dojo",
             ),
             ResourceModel(
-                'YouTube Video Series',
-                'https://www.youtube.com/watch?v=9DVK2Khx8Ys&list=PLboXykqtm8dy_DNg1NZiS08Dnyj35PWXw&index=4',
-                author='Jayanam'
+                "YouTube Video Series",
+                "https://www.youtube.com/watch?v=9DVK2Khx8Ys&list=PLboXykqtm8dy_DNg1NZiS08Dnyj35PWXw&index=4",
+                author="Jayanam",
             ),
         ],
-        'video tutorials'
+        "video tutorials",
     )
     py_non_interactive_tutorials = ResourceSection(
         [
             ResourceModel(
                 "Non-Programmer's Tutorial for Python 3",
-                'https://en.wikibooks.org/wiki/Non-Programmer%27s_Tutorial_for_Python_3',
-                author='Wikibooks',
-                description='Fairly detailed and approachable'
+                "https://en.wikibooks.org/wiki/Non-Programmer%27s_Tutorial_for_Python_3",
+                author="Wikibooks",
+                description="Fairly detailed and approachable",
             ),
             ResourceModel(
-                'Hands-on Python 3 Tutorial',
-                'http://anh.cs.luc.edu//python/hands-on/3.1/handsonHtml/index.html',
-                author='Dr. Andrew N. Harrington',
-                description='Very detailed and a bit faster paced'
+                "Hands-on Python 3 Tutorial",
+                "http://anh.cs.luc.edu//python/hands-on/3.1/handsonHtml/index.html",
+                author="Dr. Andrew N. Harrington",
+                description="Very detailed and a bit faster paced",
             ),
             ResourceModel(
-                'The Python Guru',
-                'https://thepythonguru.com/',
-                description='Fast paced, this one would be good for those '
-                            'who already know programming but not Python'
+                "The Python Guru",
+                "https://thepythonguru.com/",
+                description="Fast paced, this one would be good for those "
+                "who already know programming but not Python",
             ),
         ],
-        'Text (non-interactive) tutorials'
+        "Text (non-interactive) tutorials",
     )
 
     py_resources = [
         py_video_and_interactive_tutorials,
         py_interactive_tutorials,
         py_video_tutorials,
-        py_non_interactive_tutorials
+        py_non_interactive_tutorials,
     ]
 
     excel_video_tutorials = ResourceSection(
         [
             ResourceModel(
-                'Trump Excel',
-                'https://trumpexcel.com/learn-excel/',
+                "Trump Excel",
+                "https://trumpexcel.com/learn-excel/",
             ),
             ResourceModel(
-                'Excel 2016 Tutorial',
-                'https://edu.gcfglobal.org/en/excel2016/',
-                author='GCF Global'
+                "Excel 2016 Tutorial",
+                "https://edu.gcfglobal.org/en/excel2016/",
+                author="GCF Global",
             ),
             ResourceModel(
-                'Excel Exposure',
-                'https://excelexposure.com/lesson-guide/',
-                author='Ben Currier',
-            )
+                "Excel Exposure",
+                "https://excelexposure.com/lesson-guide/",
+                author="Ben Currier",
+            ),
         ],
-        title='Video Tutorials'
+        title="Video Tutorials",
     )
 
     excel_resources = [excel_video_tutorials]
@@ -263,34 +269,34 @@ just adjust how you call print for the class. There is also a Python 3 course bu
     intro_finance_resources = ResourceSection(
         [
             ResourceModel(
-                'Finance and Capital Markets',
-                'https://www.khanacademy.org/economics-finance-domain/core-finance',
-                author='Kahn Academy'
+                "Finance and Capital Markets",
+                "https://www.khanacademy.org/economics-finance-domain/core-finance",
+                author="Kahn Academy",
             ),
             ResourceModel(
-                'Finance for Non-Finance Professionals - Coursera',
-                'https://www.coursera.org/learn/finance-for-non-finance',
-                author='James Weston'
-            )
+                "Finance for Non-Finance Professionals - Coursera",
+                "https://www.coursera.org/learn/finance-for-non-finance",
+                author="James Weston",
+            ),
         ],
-        title='Introductory Finance Courses'
+        title="Introductory Finance Courses",
     )
 
     finance_resources = [intro_finance_resources]
 
     resources = [
-        ResourceSection(py_resources, 'Python'),
-        ResourceSection(excel_resources, 'Excel'),
-        ResourceSection(finance_resources, 'Finance')
+        ResourceSection(py_resources, "Python"),
+        ResourceSection(excel_resources, "Excel"),
+        ResourceSection(finance_resources, "Finance"),
     ]
 
     data = dict(
-        title='Financial Modeling',
+        title="Financial Modeling",
         description="""
 Financial modeling course which focuses on using Python and Excel to understand
 personal finance and valuation problems.
         """.strip(),
-        highlight_description='senior capstone Python and Excel-based course',
+        highlight_description="senior capstone Python and Excel-based course",
         long_description="""
 This course covers the full financial modeling workflow using both Excel and Python. I will try to teach you
 how to build a model in general, all the way from concept and data collection to the result and visualization,
@@ -299,23 +305,23 @@ would be applicable in a finance job, and more so than any other course you’ve
 be very challenging for the less technically inclined, but I will try to help everyone succeed.
         """.strip(),
         evaluation_score=4.5,
-        periods_taught=['Fall 2019', 'Spring 2020', 'Fall 2020'],
+        periods_taught=["Fall 2019", "Spring 2020", "Fall 2020"],
         university=UF,
-        course_id='FIN 4934',
-        current_period='Fall 2020',
-        current_time='Fully Online, Asynchronous',
-        office_hours='TBD',
+        course_id="FIN 4934",
+        current_period="Fall 2020",
+        current_time="Fully Online, Asynchronous",
+        office_hours="TBD",
         textbook=default_textbook,
-        daily_prep='Have a computer with Microsoft Excel 2007 or newer ready. We will be installing Python '
-                   'on this machine as well.',
+        daily_prep="Have a computer with Microsoft Excel 2007 or newer ready. We will be installing Python "
+        "on this machine as well.",
         prerequisites=default_prereqs,
         class_structure_body=default_class_structure,
         grading=default_grading_model,
         topics=FIN_MODEL_COURSE_MAIN_CATEGORIES,
-        website_url='https://nickderobertis.github.io/fin-model-course',
+        website_url="https://nickderobertis.github.io/fin-model-course",
         software_projects=default_software_projects,
         resources=resources,
     )
     data.update(overrides)
 
-    return CourseModel(**data)
\ No newline at end of file
+    return CourseModel(**data)
