@@ -1,15 +1,15 @@
 from copy import deepcopy
-from typing import Sequence, Optional, List
+from typing import List, Optional, Sequence
 
 from pyexlatex.logic.format.and_join import join_with_commas_and_and_output_list
 
 RESEARCH_INTERESTS = [
-    'FinTech',
-    'empirical asset pricing',
-    'behavioral finance',
-    'monetary policy',
-    'empirical corporate finance',
-    'market microstructure',
+    "FinTech",
+    "empirical asset pricing",
+    "behavioral finance",
+    "monetary policy",
+    "empirical corporate finance",
+    "market microstructure",
 ]
 
 
