@@ -1,14 +1,22 @@
-from typing import List, Dict, Optional, Sequence
+from typing import Dict, List, Optional, Sequence
 
+from derobertis_cv.pldata.software.yaml_.config import (
+    ADD_DESCRIPTIONS,
+    DISPLAY_TITLES,
+    RENAME_MAP,
+    REPLACE_DESCRIPTIONS,
+    REPLACE_LOGO_FA_CLASS_STRS,
+    REPLACE_LOGO_FILES,
+    REPLACE_LOGO_URLS,
+    REPLACE_URLS,
+)
 from derobertis_cv.pltemplates.logo import image_base64
 from derobertis_cv.pltemplates.software.project import SoftwareProject
-from derobertis_cv.pldata.software.yaml_.config import DISPLAY_TITLES, RENAME_MAP, ADD_DESCRIPTIONS, \
-    REPLACE_DESCRIPTIONS, \
-    REPLACE_URLS, REPLACE_LOGO_URLS, REPLACE_LOGO_FILES, REPLACE_LOGO_FA_CLASS_STRS
 
 
-def apply_modifications_to_projects(projects: List[SoftwareProject],
-                                    order: Optional[Sequence[str]] = None) -> List[SoftwareProject]:
+def apply_modifications_to_projects(
+    projects: List[SoftwareProject], order: Optional[Sequence[str]] = None
+) -> List[SoftwareProject]:
     projects_dict = _projects_dict(projects)
     for title, display_title in DISPLAY_TITLES.items():
         if title in projects_dict:
@@ -39,10 +47,9 @@ def apply_modifications_to_projects(projects: List[SoftwareProject],
     # Strip extra spacing on descriptions
     for project in projects_dict.values():
         if project.description is None:
-            project.description = ''
+            project.description = ""
         project.description = project.description.strip()
 
-
     projects = list(projects_dict.values())
 
     if order is not None:
@@ -59,5 +66,3 @@ def apply_modifications_to_projects(projects: List[SoftwareProject],
 
 def _projects_dict(projects: List[SoftwareProject]) -> Dict[str, SoftwareProject]:
     return {project.title: project for project in projects}
-
-
