@@ -27,9 +27,9 @@ def image_base64(file_name: str) -> str:
     image_type = file_extension.lower()
 
     file_path = os.path.join(IMAGES_PATH, file_name)
-    with open(file_path, 'rb') as f:
+    with open(file_path, "rb") as f:
         contents = f.read()
-    b64 = base64.b64encode(contents).decode('utf8')
+    b64 = base64.b64encode(contents).decode("utf8")
     src = f"data:image/{image_type};base64,{b64}"
     return src
 
@@ -37,5 +37,5 @@ def image_base64(file_name: str) -> str:
 def svg_text(file_name: str) -> str:
     file_path = os.path.join(IMAGES_PATH, file_name)
     contents = pathlib.Path(file_path).read_text()
-    content_idx = contents.find('<svg')
+    content_idx = contents.find("<svg")
     return contents[content_idx:]
