@@ -2,12 +2,13 @@ from typing import TYPE_CHECKING, cast
 
 if TYPE_CHECKING:
     from derobertis_cv.pltemplates.software.project import SoftwareProject
+
 from copy import deepcopy
+
 import pyexlatex.resume as lr
 
 
 class SoftwareSection(lr.SpacedSection):
-
     def __init__(self, contents, compact: bool = False, **kwargs):
         if not isinstance(contents, (list, tuple)):
             contents = [contents]
@@ -16,10 +17,13 @@ class SoftwareSection(lr.SpacedSection):
 
         if compact:
             for content in contents:
-                if hasattr(content, 'is_SoftwareProject') and content.is_SoftwareProject:
-                    content = cast('SoftwareProject', content)
+                if (
+                    hasattr(content, "is_SoftwareProject")
+                    and content.is_SoftwareProject
+                ):
+                    content = cast("SoftwareProject", content)
                     content.compact = True
                     # Refresh output
                     content.contents = content._get_contents()
 
-        super().__init__(contents, **kwargs)
\ No newline at end of file
+        super().__init__(contents, **kwargs)
